.. ref_videofx:

************
video.fx
************
This module regroups functions meant to be used with ``videoclip.fx``. When you type ``from moviepy import *``, the module ``video.fx`` is loaded as ``vfx`` and you can use ``vfx.colorx``, ``vfx.resize``, etc.


.. automodule:: moviepy.video.fx
   :members:
   :show-inheritance:
